Avocado VT Plugin
=================

Avocado-VT is a compatibility plugin that lets you execute virtualization
related tests (then known as virt-test), with all conveniences provided by
Avocado.

Gettings started with Avocado
=============================

First of all, make sure you have Avocado itself installed. You can check
the Avocado online documentation at:

https://avocado-framework.readthedocs.io/en/latest/guides/user/chapters/installing.html

Getting started with Avocado-VT
===============================

The recommended way of installing Avocado-VT is through RPM packages.
Documentation on how to install it can be found at:

http://avocado-vt.readthedocs.org/en/latest/GetStartedGuide.html
